@@ -158,11 +158,11 @@ def download(
     else:
         filename_from_url = osp.basename(url)
 
-    output_is_path = isinstance(output, six.string_types)
-
     if output is None:
         output = filename_from_url
-    elif output_is_path and output.endswith(osp.sep):
+
+    output_is_path = isinstance(output, six.string_types)
+    if output_is_path and output.endswith(osp.sep):
         if not osp.exists(output):
             os.makedirs(output)
         output = osp.join(output, filename_from_url)
